//
//  Imager100.h
//  ATIKOSXDrivers
//
//  Created by Nick Kitchener on 04/11/2012.
//  Copyright (c) 2012 ATIK. All rights reserved.
//

// The Imager100 protocol is a generic imager protocol.
// All camera objects support this.

#import <Foundation/Foundation.h>
#import "ServiceInterface.h"
#import "ImageFrame.h"
#import "Cooling100.h"

// Provides useful camera imager properties.
@protocol ImagerProperties100 <NSObject>
-(uint32_t)xPixels; // total number of X pixels
-(uint32_t)yPixels; // total number of Y pixels

-(uint32_t)maxBinX; // maximum binning in X supported
-(uint32_t)maxBinY; // maximum binning in Y supported

// properties to show if these are supported.
-(BOOL)isBinningSupported;
-(BOOL)isSubframingSupported;
-(BOOL)isPreviewSupported;

@end

@protocol Imager100 <NSObject, ServiceInterface, ImagerProperties100>

// This allows the camera to peform some validation checking and buffer
// size allocation with the image frame.
// This should be called each time a frame is used.
-(void)prepare:(ImageFrame*)image;

// This allows the camera to perform any post processing required.
// It should be called each time a frame snapshot have been completed.
-(void)postProcess:(ImageFrame*)image;

// This takes an image 
-(void)snapShot:(ImageFrame*)image blocking:(BOOL)shouldBlock;

//
-(id<Cooling100>)cooling;

@end
