//
//  ATIKOSXLegacyDrivers.h
//  ATIKOSXLegacyDrivers
//
//  Created by Nick Kitchener on 07/12/2012.
//  Copyright (c) 2012 ATIK. All rights reserved.
//

#include <ATIKOSXDrivers/ATIKOSXDrivers.h>
#import <IOKit/hid/IOHIDLib.h>
#include <IOKit/usb/IOUSBLib.h>
#include <IOKit/IOCFPlugIn.h>



@interface ATIKOSXLegacyDrivers : NSObject {
    
@private
    io_iterator_t           attachIterator;
    io_iterator_t           detachIterator;
    NSMutableDictionary     *connectedDevices;
    NSMutableDictionary     *availableDevices;
    NSMutableDictionary     *ftdiChipIds;
    //id<USBCallbackDelegate> delegate;
    NSData                  *firmwareHexData;
    id<ATIKOSXDriverNotificationDelegate> _notificationDelegate;
}

-(id)init;

-(void)startSupport;
-(void)endSupport;
-(void)registerFTDIChipId:(int)chipId forUSBSerialNumber:(NSString*)sn;

-(id<Services>)serviceManagement;

@end

@interface ATIKOSXLegacyDrivers (Private)
-(void)setUpUSBHooks;
-(void)clearUSBHooks;
-(void)addDeviceHookForVendor:(SInt32)usbVendor product:(SInt32)usbProduct bcd:(SInt32)usbBcdNumber;

-(CFMutableDictionaryRef)matchingDeviceDictionaryWith:(SInt32)usbVendor product:(SInt32)usbProduct bcd:(SInt32)usbBcdNumber;
-(CFMutableDictionaryRef)matchingInterfaceDictionaryWith:(SInt32)usbVendor
                                                 product:(SInt32)usbProduct
                                                     bcd:(SInt32)usbBcdNumber
                                           configuration:(SInt32)usbConfigurationValue
                                               interface:(SInt32)usbInterfaceNumber;

-(void)deviceAttach:(io_iterator_t)iterator;
-(void)deviceDetach:(io_iterator_t)iterator;

-(UInt32)addressFromService:(io_service_t)service;

-(void)usbDeviceList;

-(void) usbCharactersToHostCharacters:(UniChar*)buf  count:(int) cnt;
-(OSStatus) stringDescriptor:(IOUSBDeviceInterface320**)deviceInterface forIndex:(UInt8)stringIndex inBuffer:(char*)outBuffer max:(int)maxLen;

@end

@interface ATIKOSXLegacyDrivers (Services) <Services>

-(NSDictionary*)availableServices;
-(id<ServiceInterface>)claimService:(NSString*)serviceIdentifier;
-(void)releaseService:(id<ServiceInterface>)serviceInstance;
-(void)setNotificationDelegate:(id<ATIKOSXDriverNotificationDelegate>)delegate;

@end

